![pysitemaps feature image](docs/img/feature-image.png)

# pysitemaps: Python Package for Sitemaps

``pysitemaps`` package can be used to (systematically) generate and analyze sitemaps.

## Whats in pysitemaps?

We believe in monolithic software development and created this tiny package that does its job without any bloat. 

## How to Use pysitemaps?

You can find detailed tutorial on [pysitemaps tutorial website](https://serpwings.com/software/python-sitemaps/).

## Contribute

Pull Requests, Feature Suggestions, and collaborations are welcome.

## About Us

This work is a collaborative effort of [seowings](https://seowings.org/), and [serpwings](https://serpwings.com/).
